'''
Define list from https://sourceforge.net/p/nikkhokkho/code/HEAD/tree/trunk/FileOptimizer/Source/cppMain.h
commit ver [r1569] 2020-08-02
Author of original cpp code: Nikkho
'''
KS_EXTENSION_BMP = (".bmp", ".dib",)
KS_EXTENSION_CSS = (".css",)
KS_EXTENSION_DLL = (".dll", ".bpl", ".cpl", ".drv", ".icl", ".lzl", ".ocx", ".rll", ".sys", ".vbx",)
KS_EXTENSION_EXE = (".exe", ".scr",)
KS_EXTENSION_FLAC = (".flac",)
KS_EXTENSION_GIF = (".gif",)
KS_EXTENSION_GZ = (".gz", ".deb", ".ipk", ".tgz", ".svgz", ".vlt",)
KS_EXTENSION_HTML = (".htm", ".html", ".mht", ".mhtml", ".xhtml", ".xml", ".sgml", ".svg",)
KS_EXTENSION_ICO = (".ico", ".cur", ".spl",)
KS_EXTENSION_JPG = (".jfi", ".jif", ".jfif", ".jng", ".jpe", ".jpg", ".jpeg", ".thm", ".mpo", ".jps",)
KS_EXTENSION_JS = (".js", ".json",)
KS_EXTENSION_LUA = (".lua", ".luac",)
KS_EXTENSION_MIME = (".mht", ".mhtml", ".eml", ".emlx", ".msg", ".mbx", ".vcf", ".vcard",)
KS_EXTENSION_MKV = (".mkv", ".mka", ".mks", ".mk3d", ".webm", ".weba",)
KS_EXTENSION_MNG = (".mng",)
KS_EXTENSION_MP3 = (".mp3",)
KS_EXTENSION_MP4 = (".mp4", ".3gp", ".3gg", ".3g2", ".m4a", ".m4b", ".m4p", ".m4r", ".m4v", ".acc", ".avi", ".mpg", ".mpeg", ".vob", ".flv", ".wmv", ".wma", ".rv", ".ra", ".rm", ".rmvb", ".ram", ".smil", ".qt", ".mov",)
KS_EXTENSION_OBJ = (".obj", ".o", ".lib", ".a",)
KS_EXTENSION_OGG = (".ogg", ".oga", ".ogx",)
KS_EXTENSION_OGV = (".ogg", ".ogv", ".ogx",)
KS_EXTENSION_OLE = (".ac", ".adp", ".apr", ".art", ".chm", ".chi", ".chq", ".chs", ".chw", ".db", ".doc", ".dot", ".fla", ".fpx", ".its", ".lit", ".max", ".mce", ".mdb", ".mdt", ".mic", ".mix", ".mpd", ".mpp", ".mpt", ".msc", ".msi", ".msg", ".msp", ".mst", ".mtw", ".mzz", ".ole", ".ole2", ".one", ".opt", ".ost", ".pps", ".ppt", ".pub", ".puz", ".rfa", ".rft", ".rte", ".rvt", ".sldasm", ".sldprt", ".slddrw", ".sou", ".spo stickynotes.snt thumbs.db", ".vsd", ".vst", ".vss", ".wiz", ".wps", ".xl", ".xla", ".xlc", ".xlm", ".xls", ".xlw", ".xsf", ".xsn",)
KS_EXTENSION_PCX = (".dcx", ".pcc", ".pcx",)
KS_EXTENSION_PDF = (".epdf", ".pdf", ".fdf", ".ai",)
KS_EXTENSION_PNG = (".apng", ".ico", ".png", ".pns",)
KS_EXTENSION_SQLITE = (".sqlite", ".sqlite3", ".sqlite2", ".db",)
KS_EXTENSION_SWF = (".swf",)
KS_EXTENSION_TAR = (".tar", ".cbt",)
KS_EXTENSION_TGA = (".tga", ".icb", ".vda", ".vst",)
KS_EXTENSION_TIFF = (".fax", ".tif", ".tiff", ".ptif", ".ptiff",)
KS_EXTENSION_WAV = (".wav",)
KS_EXTENSION_TENCENTQQ = (".gft", ".rdb",)
KS_EXTENSION_WEBP = (".webp",)
KS_EXTENSION_XML = (".xml", ".fb2", ".fxg", ".kml", ".xsl", ".xslt", ".xhtml",)
KS_EXTENSION_ZIP = (".air", ".apk", ".appx", ".bar", ".bsz", ".cbz", ".cdr", ".cdt", ".csl", ".des", ".docm", ".docx", ".dotx", ".dotm", ".dwf", ".dwfx", ".ear", ".easm", ".eprt", ".epub", ".fxg", ".gallery", ".gallerycollection", ".galleryitem", ".grs", ".ink", ".ipsw", ".itz", ".ipa", ".ita", ".jar", ".kmz", ".ksf", ".kmz", ".lxf", ".mdz", ".miz", ".mmip", ".mvz", ".mpp", ".msz", ".nar", ".nbk", ".notebook", ".ora", ".odb", ".odf", ".odg", ".odp", ".ods", ".odt", ".oex", ".osk", ".oxps", ".pk3", ".ppam", ".potm", ".potx", ".ppsm", ".ppsx", ".pptm", ".pptx", ".pub", ".qwk", ".r2skin", ".rdb", ".rmskin", ".s3z", ".sldm", ".sldx", ".stz", ".swc", ".vdx", ".vtx", ".vsx", ".wal", ".war", ".wba", ".wmz", ".wsz", ".xap", ".xlam", ".xlsb", ".xlsm", ".xlsx", ".xltm", ".xltx", ".xnk", ".xmz", ".xpi", ".xps", ".z01", ".z02", ".z03", ".z04", ".z05", ".z06", ".z07", ".z08", ".z09", ".z10", ".zip", ".zx01", ".zx02", ".zx03", ".zx04", ".zx05", ".zx05", ".zx06", ".zx07", ".zx08", ".zx09", ".zx10", ".zipx",)
KS_EXTENSION_7Z = (".7z", ".lzma",)
KS_EXTENSION_MISC = (".aai", ".art", ".avs", ".bpg", ".cin", ".cmyk", ".cmyka", ".dds", ".dpx", ".epdf", ".fax", ".fits", ".fpx", ".gray", ".hdr", ".hrz", ".inline", ".jp2", ".j2c", ".j2k", ".jpc", ".jpt", ".mono", ".mif", ".miff", ".mpc", ".mpr", ".msl", ".mtv", ".mvg", ".otb", ".p7", ".palm", ".pcd", ".pcds", ".pcl", ".pcls", ".pdb", ".pbm", ".pfs", ".pfm", ".pgm", ".picon", ".pic", ".pict", ".pnm", ".ppm", ".psb", ".psd", ".ptif", ".ptiff", ".rfg", ".rgb", ".rgba", ".sgi", ".sun", ".uyvy", ".vicar", ".viff", ".wbmp", ".x", ".xbm", ".xpm", ".xwd", ".ycbr", ".ycbra", ".yub",)


import argparse
from .main import optimiseDir

def main():
   parser = argparse.ArgumentParser();
   parser.add_argument('input',nargs='*',help='input file');
   parser.add_argument('-s','--silent', action='store_true', help='run without output print');
   args = parser.parse_args();
   deduped_input = []
   for inputfile in args.input:
      if inputfile not in deduped_input:
         deduped_input.append(inputfile);
   for inputfile in deduped_input:
      optimiseDir(inputfile, silentMode=args.silent)

if __name__ == "__main__":
    main()